@@ -8,6 +8,7 @@
 ##======================================================================
 
 package DDC::PP::yyqlexer;
+use 5.010;  ##-- we need at least v5.10.0 for /p regex modifier
 use Encode qw(encode_utf8 decode_utf8);
 use Carp;
 use IO::File;
@@ -28,20 +29,20 @@ BEGIN {
   %DEF =
     (
      ##-- copied from ddc-2.0.43/src/ConcordLib/yyQLexer.l ; extra escapes needed for backslashes ('\\' -> '\\\\')
-     'ws' => '[ \t\n\r\f\v]',
+     'ws' => '[ \t\n\r\f\x0b]',
      'punct' => '[\^\!\~\$\@\%\/\=\?\_\:\;\+\#\.\\\\\*\,\'\"\&\|\(\)\[\]\{\}\<\>]',
 
-     int_boundary => '[ \t\n\r\f\v\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\~\\\\\$\@\/\?\_\+\-\.]',
-     kw_boundary  => '[ \t\n\r\f\v\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\~\\\\\$\@\/\?\_\+\-\.]',
+     int_boundary => '[ \t\n\r\f\x0b\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\~\\\\\$\@\/\?\_\+\-\.]',
+     kw_boundary  => '[ \t\n\r\f\x0b\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\~\\\\\$\@\/\?\_\+\-\.]',
 
-     ssymbol_cfirst => '[^ \t\r\n\f\v\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\\\\\~\/\$\@\?\_\+\.0-9]',
-     ssymbol_crest  => '[^ \t\r\n\f\v\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\\\\\~\/]',
+     ssymbol_cfirst => '[^ \t\r\n\f\x0b\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\\\\\~\/\$\@\?\_\+\.0-9]',
+     ssymbol_crest  => '[^ \t\r\n\f\x0b\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\\\\\~\/]',
      symbol_cescape => '(?:\\\\.)',
 
      isymbol_cfirst  => '[0-9]',
-     isymbol_crest   => '[^ \t\r\n\f\v\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\\\\\~\/\$\@\?\_\+\-\.]',
+     isymbol_crest   => '[^ \t\r\n\f\x0b\0\^\&\|\!\(\)\[\]\{\}\<\>\'\"\,\;\:\#\=\*\%\\\\\~\/\$\@\?\_\+\-\.]',
 
-     'int_boundary' => '[ \t\n\r\f\v\0\^\!\~\$\@\%\/\=\?\_\:\;\+\#\.\\\\\*\,\'\"\&\|\(\)\[\]\{\}\<\>]',
+     'int_boundary' => '[ \t\n\r\f\x0b\0\^\!\~\$\@\%\/\=\?\_\:\;\+\#\.\\\\\*\,\'\"\&\|\(\)\[\]\{\}\<\>]',
     );
 
   $DEF{ssymbol_text} = "(?:$DEF{symbol_cescape}|$DEF{ssymbol_cfirst})(?:$DEF{symbol_cescape}|$DEF{ssymbol_crest})*";
@@ -291,7 +292,7 @@ sub yylex {
       if ($lex->{state} eq 'INITIAL') {
 
 	##-- end-of-file (should be first pattern)
-	if    ($$bufr =~ m/\G\z/)		{ $type = '__EOF__'; }
+	if    ($$bufr =~ m/\G\z/)	{ $type = '__EOF__'; }
 
 	##-- operators
 	elsif ($$bufr =~ m/\G\&\&/p)	{ $type = 'OP_BOOL_AND'; }
